<?php

namespace Lavalite\Gallery\Providers;

use Illuminate\Support\ServiceProvider;

class GalleryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'gallery');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'gallery');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('lavalite.gallery', function ($app) {
            return $this->app->make('Lavalite\Gallery\Gallery');
        });

        // Bind Gallery to repository
        $this->app->bind(
            'Lavalite\Gallery\Interfaces\GalleryRepositoryInterface',
            \Lavalite\Gallery\Repositories\Eloquent\GalleryRepository::class
        );
        // Bind Category to repository
        $this->app->bind(
            'Lavalite\Gallery\Interfaces\CategoryRepositoryInterface',
            \Lavalite\Gallery\Repositories\Eloquent\CategoryRepository::class
        );

        $this->app->register(\Lavalite\Gallery\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Lavalite\Gallery\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['lavalite.gallery'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('lavalite/gallery.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/gallery')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/gallery')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
